@@ -1,6 +1,6 @@
 #
 # This file is part of Audio::MPD
-# Copyright (c) 2007 Jerome Quelin, all rights reserved.
+# Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -28,7 +28,7 @@ __PACKAGE__->mk_accessors(
         collection playlist version ] );
 
 
-our $VERSION = '0.19.0';
+our $VERSION = '0.19.3';
 
 Readonly our $REUSE => 0;
 Readonly our $ONCE  => 1;
@@ -183,9 +183,9 @@ sub _cooked_command_as_items {
     # of course, since we want to preserve the playlist order, this means
     # that we're going to unshift the objects instead of push.
     foreach my $line (reverse @lines) {
-        my ($k,$v) = split /:\s+/, $line, 2;
+        my ($k,$v) = split /:\s/, $line, 2;
         $param{$k} = $v;
-        next unless $k eq 'file' || $k eq 'directory'; # last param of item
+        next unless $k eq 'file' || $k eq 'directory' || $k eq 'playlist'; # last param of item
         unshift @items, Audio::MPD::Common::Item->new(%param);
         %param = ();
     }
@@ -205,7 +205,7 @@ sub _cooked_command_as_items {
 sub _cooked_command_as_kv {
     my ($self, $command) = @_;
     my %hash =
-        map { split(/:\s+/, $_, 2) }
+        map { split(/:\s/, $_, 2) }
         $self->_send_command($command);
     return %hash;
 }
@@ -655,7 +655,11 @@ Sends a ping command to the mpd server.
 
 =item $mpd->version()
 
-Return the version number for the server we are connected to.
+Return mpd's version number as advertised during connection. Note that
+mpd returns B<protocol> version when connected. This protocol version
+can differ from the real mpd version. eg, mpd version 0.13.2 is
+"speaking" and thus advertising version 0.13.0.
+
 
 
 =item $mpd->kill()
@@ -868,7 +872,7 @@ documented by Nicholas J. Humfrey C<< <njh at aelius.com> >>.
 
 Copyright (c) 2005 Tue Abrahamsen, all rights reserved.
 Copyright (c) 2006 Nicolas J. Humfrey, all rights reserved.
-Copyright (c) 2007 Jerome Quelin, all rights reserved.
+Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
