@@ -1,6 +1,6 @@
 #
 # This file is part of Audio::MPD
-# Copyright (c) 2007 Jerome Quelin, all rights reserved.
+# Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
@@ -167,6 +167,21 @@ sub all_pathes {
 }
 
 
+#
+# my @items = $collection->all_playlists;
+#
+# Return the list of playlists (strings) currently known by mpd.
+#
+sub all_playlists {
+    my ($self) = @_;
+
+    return
+        map { /^playlist: (.*)$/ ? ($1) : () }
+        $self->_mpd->_send_command( "lsinfo\n" );
+}
+
+
+
 # -- Collection: picking songs
 
 #
@@ -400,6 +415,11 @@ Return the list of all song titles (strings) currently known by mpd.
 Return the list of all pathes (strings) currently known by mpd.
 
 
+=item $coll->all_playlists()
+
+Return the list of all playlists (strings) currently known by mpd.
+
+
 =back
 
 
@@ -476,7 +496,7 @@ Jerome Quelin, C<< <jquelin at cpan.org> >>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2007 Jerome Quelin, all rights reserved.
+Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
