@@ -1,17 +1,9 @@
 #
+# This file is part of Audio::MPD
+# Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
+#
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# it under the same terms as Perl itself.
 #
 #
 
@@ -27,7 +19,7 @@ use Readonly;
 
 use base qw[ Exporter ];
 our @EXPORT = qw[ customize_test_mpd_configuration start_test_mpd stop_test_mpd ];
-#our ($VERSION) = '$Rev: 5727 $' =~ /(\d+)/;
+#our ($VERSION) = '$Rev: 5284 $' =~ /(\d+)/;
 
 
 Readonly my $TEMPLATE => "$Bin/mpd-test/mpd.conf.template";
@@ -205,18 +197,21 @@ by $port if specified, 6600 otherwise (MPD default).
 This might be useful when trying to test connections with mpd server.
 
 
-=head1 COPYRIGHT AND LICENSE
+=head1 SEE ALSO
 
-Copyright (c) 2007 Jerome Quelin
+L<Audio::MPD>
+
+
+=head1 AUTHOR
+
+Jerome Quelin, C<< <jquelin at cpan.org> >>
+
+
+=head1 COPYRIGHT & LICENSE
+
+Copyright (c) 2007-2008 Jerome Quelin, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+it under the same terms as Perl itself.
 
 =cut
